@@ -5,9 +5,10 @@ from astropy.io import fits
 import numpy as np
 import matplotlib.pyplot as plt
 import pandas as pd
-from hstgrism.confreader import ConfReader
-from hstgrism.computesip import ComputeSIP
-from hstgrism.computetracenwavelength import ComputeTraceNWavelength
+import copy
+from .confreader import ConfReader
+from .computesip import ComputeSIP
+from .computetracenwavelength import ComputeTraceNWavelength
 
 class Wfc3Uvis1G280:
     def __init__(self,objname='None',dfile=None,gfile=None,extnum=4,
@@ -47,6 +48,7 @@ class Wfc3Uvis1G280:
             print('Cannot find ROOTNAME for {0}.\n'.format(self.data['gfile']))
     def _get_ccdchip(self):
         try:
+            EXTNUM = self.data['extnum']
             tmp = fits.open(self.data['gfile'])[EXTNUM].header['CCDCHIP']
             self.data['CCDCHIP'] = tmp
         except:
@@ -120,7 +122,6 @@ class Wfc3Uvis1G280:
              figsize=(10,10),fontsize=12
             ):
         EXTNUM = self.data['extnum']
-        fname = self.data['gfile'].split('/')[-1]
         pixx,pixy = self.data['xyd'][0],self.data['xyd'][1]
         OBJNAME = self.data['objname']
         root = self.data['ROOTNAME']
@@ -138,6 +139,7 @@ class Wfc3Uvis1G280:
         vmin,vmax = np.percentile(tmppdata,dminmax[0]),np.percentile(tmppdata,dminmax[1])
         ax1.imshow(tmppdata,origin='lower',cmap='viridis',vmin=vmin,vmax=vmax)
         ax1.scatter(pixx,pixy,s=30,facecolor='None',edgecolor='red')
+        fname = self.data['dfile'].split('/')[-1]
         string = '{0} {1} {2} SUBARRAY={3}\n'.format(fname,tmpheader['DATE-OBS'],tmpheader['FILTER'],tmpheader['SUBARRAY'])
         string += 'EXPSTART={0:.3f} EXPTIME={1:.3f}\n'.format(tmpheader['EXPSTART'],tmpheader['EXPTIME'])
         string += 'EXTNUM={0} CCDCHIP={1} BUNIT={2}'.format(EXTNUM,tmppheader['CCDCHIP'],tmppheader['BUNIT'])
@@ -161,6 +163,7 @@ class Wfc3Uvis1G280:
         vmin,vmax = np.percentile(tmppdata,gminmax[0]),np.percentile(tmppdata,gminmax[1])
         ax3.imshow(tmppdata,origin='lower',cmap='viridis',vmin=vmin,vmax=vmax)
         ax3.plot(xg,yg,'r-',alpha=alpha,lw=lw)
+        fname = self.data['gfile'].split('/')[-1]
         string = '{0} {1} {2} SUBARRAY={3}\n'.format(fname,tmpheader['DATE-OBS'],tmpheader['FILTER'],tmpheader['SUBARRAY'])
         string += 'EXPSTART={0:.3f} EXPTIME={1:.3f}\n'.format(tmpheader['EXPSTART'],tmpheader['EXPTIME'])
         string += 'EXTNUM={0} CCDCHIP={1} BUNIT={2}'.format(EXTNUM,tmppheader['CCDCHIP'],tmppheader['BUNIT'])
